// Copyright (c) 2016, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by an AGPL-3.0-style license
// that can be found in the LICENSE file.

part of molview_pubchem.module.compounds;

const pubchemAutocompleteApiRoot =
    'https://pubchem.ncbi.nlm.nih.gov/pcautocp/pcautocp.cgi';
const pubchemCompoundsDict = 'pc_compoundnames';

/// Find compound search suggestions using the PubChem autocomplete API.
///
/// Reference:
/// https://pubchem.ncbi.nlm.nih.gov/widget/docs/widget_autocomplete_help.html
Future<v0.SearchSuggestions> findSuggestions(
    v0.FindSearchSuggestions query) async {
  var requestUrl =
      '$pubchemAutocompleteApiRoot?dict=$pubchemCompoundsDict&q=${query.text}&n=${query.count}';

  // Execute request.
  Map<String, dynamic> response = JSON
      .decode((await httpClient.get(requestUrl)).body) as Map<String, dynamic>;

  // Extract suggestions.
  var suggestions = new List<SearchSuggestion>();
  List<String> autocpArray = response['autocp_array'] as List<String>;
  autocpArray.forEach(
      (String title) => suggestions.add(new SearchSuggestion(title, null)));

  return new v0.SearchSuggestions(
      'pubchem', 'compounds', fields.nullKey, suggestions);
}
